@@ -36,7 +36,7 @@ class GBMFitter:
         self.training_data = {'CB': cb_data, 'XGB': xgb_data, 'LGB': lgb_data}
         self.models = {'CB': [], 'XGB': [], 'LGB': []}  # for each category, generates folds models
         self.rounders = {'CB': [], 'XGB': [], 'LGB': []}
-        self.oof = {'CB': []}
+        self.oof = {'CB': [], 'XGB': [], 'LGB': []}
         self.fselection = {}
 
         self.cv_groups = cv_groups
